@@ -31,6 +31,7 @@
 #include "cursors.h"
 #include "image-view.h"
 #include "uta.h"
+#include "lcms.h"
 
 /* Checks */
 
@@ -114,6 +115,7 @@ struct _ImageViewPrivate {
 #ifdef LIBEOG_ETTORE_CHANGES
 	float display_brightness;
 	float display_contrast;
+	cmsHTRANSFORM transform;
 #endif
 };
 
@@ -260,6 +262,7 @@ image_view_instance_init (ImageView *view)
 #ifdef LIBEOG_ETTORE_CHANGES
 	priv->display_brightness = 0.0;
 	priv->display_contrast = 0.0;
+	priv->transform = NULL;
 #endif
 
 	/* We don't want to be double-buffered as we are SuperSmart(tm) */
@@ -528,6 +531,22 @@ apply_brightness_and_contrast_to_pixbuf (ImageView *view,
 	}
 }
 
+apply_transform_to_pixbuf (ImageView *view, GdkPixbuf *pixbuf, int width, int height)
+{
+	char *p;
+	int line;
+	int rowstride;
+	int bytes_per_pixel;
+
+	p = gdk_pixbuf_get_pixels (pixbuf);
+	rowstride = gdk_pixbuf_get_rowstride (pixbuf);
+	bytes_per_pixel = gdk_pixbuf_get_has_alpha (pixbuf) ? 4 : 3;
+
+	for (line = 0; line < height; line ++) {
+		cmsDoTransform (view->priv->transform, p, p, width);
+		p += rowstride;
+	}
+}
 #endif
 
 /* Paints a rectangle of the dirty region */
@@ -631,7 +650,8 @@ paint_rectangle (ImageView *view, ArtIRect *rect, GdkInterpType interp_type)
 	if (unity_zoom (priv)
 	    && gdk_pixbuf_get_colorspace (priv->pixbuf) == GDK_COLORSPACE_RGB
 	    && !gdk_pixbuf_get_has_alpha (priv->pixbuf)
-	    && gdk_pixbuf_get_bits_per_sample (priv->pixbuf) == 8) {
+	    && gdk_pixbuf_get_bits_per_sample (priv->pixbuf) == 8
+	    && priv->transform == NULL) {
 		guchar *pixels;
 		int rowstride;
 
@@ -740,7 +760,10 @@ paint_rectangle (ImageView *view, ArtIRect *rect, GdkInterpType interp_type)
 
 #ifdef LIBEOG_ETTORE_CHANGES
 	if (apply_brightness_and_contrast)
-	apply_brightness_and_contrast_to_pixbuf (view, tmp, d.x1 - d.x0, d.y1 - d.y0);
+		apply_brightness_and_contrast_to_pixbuf (view, tmp, d.x1 - d.x0, d.y1 - d.y0);
+
+	if (priv->transform != NULL)
+		apply_transform_to_pixbuf (view, tmp, d.x1 - d.x0, d.y1 - d.y0);
 #endif
 
 #ifdef PACK_RGBA
@@ -1527,12 +1550,12 @@ image_view_key_press_event (GtkWidget *widget, GdkEventKey *event)
 		do_zoom = TRUE;
 		zoomx = zoomy = 1.0;
 		break;
-
+		/* NOTE Larry disabled this binding 
 	case GDK_F:
 	case GDK_f:
 		g_signal_emit (view, image_view_signals [ZOOM_FIT], 0);
 		break;
-
+		*/
 	default:
 		goto out;
 	}
@@ -2195,4 +2218,10 @@ image_view_set_display_contrast (ImageView *view,
 	gtk_widget_queue_draw (GTK_WIDGET (view));
 }
 
+void
+image_view_set_display_transform (ImageView *view, cmsHTRANSFORM transform)
+{
+	view->priv->transform = transform;
+}
+
 #endif
