@@ -1059,7 +1059,7 @@ public class MainWindow {
 					string version_path = photo.GetVersionPath (version);
 					
 					final.Savev (version_path, "jpeg", null, null);
-					PhotoStore.GenerateThumbnail (version_path);
+					FSpot.ThumbnailGenerator.Create (version_path).Dispose ();
 					photo.DefaultVersionId = version;
 					query.Commit (id);
 				} catch (GLib.GException ex) {
@@ -1124,9 +1124,11 @@ public class MainWindow {
 			if (ids.Length > 0)
 				i = ids [0];
 
+			// FIXME this should be an  IBrowsableCollection.
 			photos = new Photo [query.Photos.Length];
 			Array.Copy (query.Photos, i, photos, 0, query.Photos.Length - i);
 			Array.Copy (query.Photos, 0, photos, query.Photos.Length - i, i);
+			System.Console.WriteLine (photos.Length);
 		} else {
 			photos = SelectedPhotos ();
 		}
