@@ -258,7 +258,7 @@ public class Photo : DbItem, IComparable, FSpot.IBrowsableItem {
 
 		if (create_file) {
 			File.Copy (original_path, new_path);
-			PhotoStore.GenerateThumbnail (new_path);
+			FSpot.ThumbnailGenerator.Create (new_path).Dispose ();
 		}
 
 		if (version_names == null)
@@ -325,7 +325,7 @@ public class Photo : DbItem, IComparable, FSpot.IBrowsableItem {
 	// This on the other hand does, but is O(n) with n being the number of existing tags.
 	public void AddTag (Tag tag)
 	{
-		if (! tags.Contains (tag))
+		if (!HasTag (tag))
 			AddTagUnsafely (tag);
 	}
 
@@ -341,7 +341,8 @@ public class Photo : DbItem, IComparable, FSpot.IBrowsableItem {
 
 	public void RemoveTag (Tag tag)
 	{
-		tags.Remove (tag);
+		if (HasTag (tag))
+			tags.Remove (tag);
 	}
 
 	public void RemoveTag (Tag []taglist)
@@ -352,6 +353,9 @@ public class Photo : DbItem, IComparable, FSpot.IBrowsableItem {
 
 	public bool HasTag (Tag tag)
 	{
+		if (tags == null)
+			return false;
+
 		return tags.Contains (tag);
 	}
 
@@ -439,17 +443,12 @@ public class PhotoStore : DbStore {
 		if (thumbnail != null) 
 			thumbnail.Save (Thumbnail.PathForUri (uri, ThumbnailSize.Large), "png");
 		else 
-			thumbnail = PixbufUtils.GenerateThumbnail (path);
+			thumbnail = FSpot.ThumbnailGenerator.Create (path);
 			
 		
 		return thumbnail;
 	}
 
-	public static Pixbuf GenerateThumbnail (string path)
-	{
-		return GenerateThumbnail (path, false);
-	}
-
 	public static void DeleteThumbnail (string path)
 	{
 		string uri = UriList.PathToFileUri (path).ToString ();
