@@ -26,7 +26,7 @@ namespace FSpot {
 		private ThumbnailCache preview_cache = new ThumbnailCache (50);
 
 		private int item;
-		new public int Item {
+		public int Item {
 			get {
 				return item;
 			}
@@ -61,15 +61,19 @@ namespace FSpot {
 
 		private void UpdateImage ()
 		{
-			Photo photo = view.Collection.Photos [Item];
+			FSpot.IBrowsableItem item = view.Collection.Items [Item];
 			
-			string orig_path = photo.DefaultVersionPath;
+			string orig_path = item.DefaultVersionUri.LocalPath;
+
 			Gdk.Pixbuf pixbuf = preview_cache.GetThumbnailForPath (orig_path);
 			if (pixbuf == null) {
 				// A bizarre pixbuf = hack to try to deal with cinematic displays, etc.
 				int preview_size = ((this.Screen.Width + this.Screen.Height)/2)/3;
 				try {
-					pixbuf = FSpot.PhotoLoader.LoadAtMaxSize (photo, preview_size, preview_size);
+					if (item is Photo)
+						pixbuf = FSpot.PhotoLoader.LoadAtMaxSize ((Photo)item, preview_size, preview_size);
+					else
+						pixbuf = PixbufUtils.LoadAtMaxSize (orig_path, preview_size, preview_size);
 				} catch (Exception e) {
 					pixbuf = null;
 				}
@@ -87,10 +91,10 @@ namespace FSpot {
 			}
 
 			string desc = "";
-			if (photo.Description.Length > 0)
-				desc = photo.Description + "\n";
+			if (item.Description != null && item.Description.Length > 0)
+				desc = item.Description + "\n";
 
-			desc += photo.Time.ToString () + "   " + photo.Name;			
+			desc += item.Time.ToString () + "   " + item.Name;			
 			label.Text = desc;
 		}
 
