@@ -19,8 +19,7 @@ public class PixbufSerializer {
 		Pixdata pixdata = new Pixdata ();
 
 		IntPtr error = IntPtr.Zero;
-		bool raw_ret = gdk_pixdata_deserialize (ref pixdata, (uint) data.Length, data, out error);
-		bool ret = raw_ret;
+		gdk_pixdata_deserialize (ref pixdata, (uint) data.Length, data, out error);
 
 		if (error != IntPtr.Zero)
 			throw new GLib.GException (error);
@@ -173,9 +172,16 @@ public class Category : Tag {
 	}
 }
 
+public delegate void TagCreatedHandler(Tag t);
+public delegate void TagChangedHandler(Tag t);
+public delegate void TagDeletedHandler(Tag t);
 
 public class TagStore : DbStore {
 
+	public event TagCreatedHandler TagCreated;
+	public event TagChangedHandler TagChanged;
+	public event TagDeletedHandler TagDeleted;
+	
 	Category root_category;
 	public Category RootCategory {
 		get {
@@ -365,7 +371,8 @@ public class TagStore : DbStore {
 
 		Tag tag = new Tag (category, id, name);
 		AddToCache (tag);
-
+		if (TagCreated != null)
+			TagCreated(tag);	
 		return tag;
 	}
 
@@ -378,7 +385,8 @@ public class TagStore : DbStore {
 
 		Category new_category = new Category (parent_category, id, name);
 		AddToCache (new_category);
-
+		if (TagCreated != null)
+			TagCreated(new_category);
 		return new_category;
 	}
 
@@ -411,6 +419,7 @@ public class TagStore : DbStore {
 		command.ExecuteNonQuery ();
 
 		command.Dispose ();
+		TagDeleted((Tag)item);
 	}
 
 
@@ -448,6 +457,9 @@ public class TagStore : DbStore {
 		command.ExecuteNonQuery ();
 
 		command.Dispose ();
+		
+		if (TagChanged != null)
+			TagChanged(tag);
 	}
 
 
